==> kjy-center-api-0.4.30-SNAPSHOT-WHOSAWME-wwz-0.0.18-sources.jar: cn/com/duiba/kjy/api/remoteservice/privatechat/RemotePrivateChatService.java <==
package cn.com.duiba.kjy.api.remoteservice.privatechat;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.api.dto.privatechat.*;
import cn.com.duiba.kjy.api.params.Page;
import cn.com.duiba.kjy.api.params.privatechat.*;

import java.util.List;


/**
 * 私信接口
 * @Auther: Tt(yehuawei)
 * @Date: 2019/6/28 0028 14:23
 */
@AdvancedFeignClient
public interface RemotePrivateChatService {
    /**
     * 内容页-查询是否存在未读消息
     * @param checkUnreadParam
     * @return
     */
    CheckUnreadDto checkUnread(CheckUnreadParam checkUnreadParam);

    /**
     * 聊天页-发送消息
     * @param chatSendParam
     * @return
     */
    Boolean send(ChatSendParam chatSendParam);

    /**
     * 聊天页-首次获取聊天内容
     * @param chatListParam
     * @return
     */
    ChatContentListDto list(ChatListParam chatListParam);

    /**
     * 聊天页-下拉获取历史聊天记录
     * @param chatHistoryParam
     * @return
     */
    ChatContentHistoryListDto history(ChatHistoryParam chatHistoryParam);

    /**
     * 聊天页-获取最新消息
     * @param chatNewsParam
     * @return
     */
    ChatContentNewListDto news(ChatNewsParam chatNewsParam);

    /**
     * 聊天页-消息已读
     * @param chatReadedParam
     * @return
     */
    Boolean readed(ChatReadedParam chatReadedParam);

    /**
     * 聊天列表-客户获取联络人列表
     * @return
     */
    Page<UserLinkmanDto> userLinkmanList(Long userId,Integer pageIndex, Integer pageSize);

    /**
     * 聊天列表-代理人获取联络客户列表
     * @return
     */
    Page<SellerLinkmanDto> sellerLinkmanList(Long sellerId,Integer pageIndex, Integer pageSize);

    /**
     * 聊天列表-代理人未读消息总数
     * @return
     */
    Integer sellerUnreadCount(Long sellerId);

    /**
     * 已废弃
     *
     * 分享列表-代理人分享历史列表
     * @param sellerId
     * @param pageIndex
     * @param pageSize
     * @return
     */
    Page<SellerContentBaseInfoDto> sellerContentHistory(Long sellerId, Integer pageIndex, Integer pageSize);

    /**
     * 分享列表-代理人分享历史列表
     * @param sellerId
     * @param excludeContentTypes 排除展示的类型
     * @param pageIndex
     * @param pageSize
     * @return
     */
    Page<SellerContentBaseInfoDto> sellerContentHistoryExcludeTypes(Long sellerId,
                                                        List<String> excludeContentTypes, Integer pageIndex, Integer pageSize);
}

==> kjy-center-api-0.4.41-SNAPSHOT-WHOSAWME-wwz-0.0.14-sources.jar: cn/com/duiba/kjy/api/remoteservice/privatechat/RemotePrivateChatService.java <==
package cn.com.duiba.kjy.api.remoteservice.privatechat;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.api.dto.privatechat.*;
import cn.com.duiba.kjy.api.params.Page;
import cn.com.duiba.kjy.api.params.privatechat.*;

import java.util.List;


/**
 * 私信接口
 * @Auther: Tt(yehuawei)
 * @Date: 2019/6/28 0028 14:23
 */
@AdvancedFeignClient
public interface RemotePrivateChatService {
    /**
     * 内容页-查询是否存在未读消息
     * @param checkUnreadParam
     * @return
     */
    CheckUnreadDto checkUnread(CheckUnreadParam checkUnreadParam);

    /**
     * 聊天页-发送消息
     * @param chatSendParam
     * @return
     */
    Boolean send(ChatSendParam chatSendParam);

    /**
     * 聊天页-首次获取聊天内容
     * @param chatListParam
     * @return
     */
    ChatContentListDto list(ChatListParam chatListParam);

    /**
     * 聊天页-下拉获取历史聊天记录
     * @param chatHistoryParam
     * @return
     */
    ChatContentHistoryListDto history(ChatHistoryParam chatHistoryParam);

    /**
     * 聊天页-获取最新消息
     * @param chatNewsParam
     * @return
     */
    ChatContentNewListDto news(ChatNewsParam chatNewsParam);

    /**
     * 聊天页-消息已读
     * @param chatReadedParam
     * @return
     */
    Boolean readed(ChatReadedParam chatReadedParam);

    /**
     * 聊天列表-客户获取联络人列表
     * @return
     */
    Page<UserLinkmanDto> userLinkmanList(Long userId,Integer pageIndex, Integer pageSize);

    /**
     * 聊天列表-代理人获取联络客户列表
     * @return
     */
    Page<SellerLinkmanDto> sellerLinkmanList(Long sellerId,Integer pageIndex, Integer pageSize);

    /**
     * 聊天列表-代理人未读消息总数
     * @return
     */
    Integer sellerUnreadCount(Long sellerId);

    /**
     * 分享列表-代理人分享历史列表
     * @param sellerId
     * @param excludeContentTypes 排除展示的类型
     * @param pageIndex
     * @param pageSize
     * @see cn.com.duiba.kjy.api.remoteservice.seller.RemoteSellerShareService
     * @return
     */
    @Deprecated
    Page<SellerContentBaseInfoDto> sellerContentHistoryExcludeTypes(Long sellerId,
                                                        List<String> excludeContentTypes, Integer pageIndex, Integer pageSize);
}
